@@ -2,8 +2,8 @@
 """
 Maxwellian shaped particle precipitation differential number flux
 """
-import glowpython2 as glow
-from glowpython2.plots import Plot 
+import glowpython as glow
+import glowpython.plots as plot
 from datetime import datetime
 from matplotlib.pyplot import show
 
@@ -20,7 +20,6 @@ Nbins = 250
 
 iono = glow.maxwellian(time, glat, glon, Nbins, Q, Echar)
 # %% plots
-plot = Plot()
 plot.precip(iono["precip"])
 plot.ver(iono)
 plot.density(iono)
