@@ -192,7 +192,7 @@
 
   SUBROUTINE GCHEM
 !
-    use cglow,only: jmax, nmaj, nex, nw, nc, kchem, sza, &
+    use cglow,only: jmax, nbins, nmaj, nex, nw, nc, kchem, sza, &
                     zz, zo, zn2, zo2, zno, zns, znd, ze, ztn, zti, zte, &
                     photoi, photod, phono, pia, sion, aglw, &
                     tei, tpi, tir, e=>ecalc, den=>zxden, zeta, zceta, vcb, &
@@ -210,7 +210,7 @@
               QQ(JMAX), RR(JMAX), SS(JMAX), TT(JMAX), UU(JMAX), &
               VV(JMAX), WW(JMAX), XX(JMAX)
     real ::   gh,dz,tatomi,alphaef,toti
-    integer :: i,iw,j200,iter
+    integer :: i,iw,ic,ix,n,j200,iter
 !
     DATA A/ 1.07E-5, 0.00585, 0.00185, 0.0450, 1.0600, 9.7E-5, 0.0479, 0.1712, 0.0010, 0.7700, &
             0.00540, 0.07900,     0.0,    0.0,    0.0,     0.0,   0.0,    0.0,    0.0,    0.0, &
@@ -238,7 +238,7 @@
 !
     DO I=1,JMAX
       GH = (RE+ZZ(I)) * SIN(SZA)
-      IF (SZA .LT. 1.6 .OR. GH .GT. RE) THEN ! sza < pi/2 or sza > pi/2 but sun not blocked by earth at high altitudes
+      IF (SZA .LT. 1.6 .OR. GH .GT. RE) THEN
         G(1,I) = 0.041
         G(2,I) = 0.013
       ENDIF
@@ -247,82 +247,79 @@
 !
 ! Calculate rate coefficients as a function of altitude:
 !
-      DO I=1,JMAX
-            T1(I) = (16.*ZTN(I)+28.*ZTI(I)) / (16.+28.) / 300. ! O and N2
-            T2(I) = (16.*ZTN(I)+32.*ZTI(I)) / (16.+32.) / 300. ! O and O2
-            T3(I) = (28.*ZTN(I)+16.*ZTI(I)) / (28.+16.) / 300. ! N2 and O+
-            T4(I) = (28.*ZTN(I)+32.*ZTI(I)) / (28.+32.) / 300. ! N2 and O2+
-            T5(I) = (16.*ZTN(I)+30.*ZTI(I)) / (16.+30.) / 300. ! O and NO+
-            IF (T1(I) .LT. 5.6667) THEN
-                  KZ(1,I) = 1.533E-12 - 5.92E-13*T1(I) + 8.6E-14*T1(I)**2
-            ELSE
-                  KZ(1,I) = 2.73E-12 - 1.155E-12*T1(I) + 1.483E-13*T1(I)**2
-            ENDIF
-            IF (T2(I) .LT. 6.6667) THEN
-                  KZ(2,I) = 3.53E-11 - 1.84E-11*T2(I) + 4.62E-12*T2(I)**2 &
-                                    - 4.95E-13*T2(I)**3 + 2.00E-14*T2(I)**4
-            ELSE
-                  KZ(2,I) = 2.82E-11 - 7.74E-12*T2(I) + 1.073E-12*T2(I)**2 &
-                                    - 5.17E-14*T2(I)**3 + 9.65E-16*T2(I)**4
-            ENDIF
-            KZ(3,I) = 1.793e-10 - 6.242e-11*T3(I) + 1.225e-11*T3(I)**2 &
-                              - 1.016e-12*T3(I)**3 + 3.087e-14*T3(I)**4
-            KZ(4,I) = 5.0E-11 * (1./T4(I)) ** 0.8
-            KZ(5,I) = 6.0E-12
-            KZ(6,I) = 6.9E-13
-            KZ(7,I) = 5.5E-10 * (ZTE(I)/300.) ** 0.5
-            KZ(8,I) = 2.0E-11 * EXP(107.8/ZTN(I))
-            KZ(9,I) = 2.9E-11 * EXP(67.5 /ZTN(I))
-            KZ(10,I) = 8.1E-10 * (ZTE(I)/300.) ** 0.5
-            KZ(11,I) = 2.0E-14
-            KZ(12,I) = 8.0E-10
-            KZ(13,I) = 7.0E-10
-            KZ(14,I) = 6.6E-08 * (300./ZTE(I)) ** 0.5
-            KZ(15,I) = 1.0E-11
-            KZ(16,I) = 4.8E-10
-            KZ(17,I) = 4.8E-10
-            KZ(18,I) = 1.7E-07 * (300./ZTE(I)) ** 0.5
-            KZ(19,I) = 5.2E-11
-            KZ(20,I) = 2.1E-11 * EXP(-1136./ZTN(I))
-            KZ(21,I) = 1.0E-13
-            KZ(22,I) = 4.2E-07 * (300./ZTE(I)) ** 0.85
-            KZ(23,I) = 1.8E-07 * (300./ZTE(I)) ** 0.39
-            IF (ZTE(I) .GE. 1200.) THEN
-                  KZ(24,I) = 1.6E-07 * (300./ZTE(I)) ** 0.55
-            ELSE
-                  KZ(24,I) = 1.95E-07 * (300./ZTE(I)) ** 0.70
-            ENDIF
-            KZ(25,I) = 6.0E-10
-            KZ(26,I) = 3.1E-11
-            KZ(27,I) = 3.0E-12
-            IF (ZTE(I) .LT. 500.) THEN
-                  KZ(28,I) = 1.0E-29
-            ELSE
-                  KZ(28,I) = 2.6E-11 * ZTE(I)**0.5 * EXP(-22740./ZTE(I))
-            ENDIF
-            KZ(29,I) = 4.1E-12
-            KZ(30,I) = 4.4E-10
-            KZ(31,I) = 7.0E-11
-            KZ(32,I) = 1.0E-12
-            KZ(33,I) = 1.2E-11
-            KZ(34,I) = 2.0E-12
-            KZ(35,I) = 1.8E-10
-            KZ(36,I) = 4.0E-12 * EXP(-865./ZTN(I))
-            KZ(37,I) = 1.2E-10
-            KZ(38,I) = 1.3E-10
-            KZ(39,I) = 2.0E-11
-            IF (T5(I) .LT. 5) THEN
-                  KZ(40,I) = 8.36E-13 - 2.02E-13*T5(I) + 6.95E-14*T5(I)**2
-            ELSE
-                  KZ(40,I) = 5.33E-13 - 1.64E-14*T5(I) + 4.72E-14*T5(I)**2 &
-                                    - 7.05E-16*T5(I)**3
-            ENDIF
-            KZ(41,I) = 7.3E-13
-            KZ(42,I) = 1.3E-15
-            KZ(43,I) = 1.0E-7
-            KZ(44,I) = 1.4E-10
-            KZ(45,I) = 4.0E-13
-      ENDDO
+    DO I=1,JMAX
+      T1(I) = (16.*ZTN(I)+28.*ZTI(I)) / (16.+28.) / 300.
+      T2(I) = (16.*ZTN(I)+32.*ZTI(I)) / (16.+32.) / 300.
+      T3(I) = (28.*ZTN(I)+16.*ZTI(I)) / (28.+16.) / 300.
+      T4(I) = (28.*ZTN(I)+32.*ZTI(I)) / (28.+32.) / 300.
+      T5(I) = (16.*ZTN(I)+30.*ZTI(I)) / (16.+30.) / 300.
+      IF (T1(I) .LT. 5.6667) THEN
+        KZ(1,I) = 1.533E-12 - 5.92E-13*T1(I) + 8.6E-14*T1(I)**2
+      ELSE
+        KZ(1,I) = 2.73E-12 - 1.155E-12*T1(I) + 1.483E-13*T1(I)**2
+      ENDIF
+      IF (T2(I) .LT. 6.6667) THEN
+        KZ(2,I) = 3.53E-11 - 1.84E-11*T2(I) + 4.62E-12*T2(I)**2 &
+                           - 4.95E-13*T2(I)**3 + 2.00E-14*T2(I)**4
+      ELSE
+        KZ(2,I) = 2.82E-11 - 7.74E-12*T2(I) + 1.073E-12*T2(I)**2 &
+                           - 5.17E-14*T2(I)**3 + 9.65E-16*T2(I)**4
+      ENDIF
+      KZ(3,I) = 1.793e-10 - 6.242e-11*T3(I) + 1.225e-11*T3(I)**2 &
+                          - 1.016e-12*T3(I)**3 + 3.087e-14*T3(I)**4
+      KZ(4,I) = 5.0E-11 * (1./T4(I)) ** 0.8
+      KZ(5,I) = 6.0E-12
+      KZ(6,I) = 6.9E-13
+      KZ(7,I) = 5.5E-10 * (ZTE(I)/300.) ** 0.5
+      KZ(8,I) = 2.0E-11 * EXP(107.8/ZTN(I))
+      KZ(9,I) = 2.9E-11 * EXP(67.5 /ZTN(I))
+      KZ(10,I) = 8.1E-10 * (ZTE(I)/300.) ** 0.5
+      KZ(11,I) = 2.0E-14
+      KZ(12,I) = 8.0E-10
+      KZ(13,I) = 7.0E-10
+      KZ(14,I) = 6.6E-08 * (300./ZTE(I)) ** 0.5
+      KZ(15,I) = 1.0E-11
+      KZ(16,I) = 4.8E-10
+      KZ(17,I) = 4.8E-10
+      KZ(18,I) = 1.7E-07 * (300./ZTE(I)) ** 0.5
+      KZ(19,I) = 5.2E-11
+      KZ(20,I) = 2.1E-11 * EXP(-1136./ZTN(I))
+      KZ(21,I) = 1.0E-13
+      KZ(22,I) = 4.2E-07 * (300./ZTE(I)) ** 0.85
+      KZ(23,I) = 1.8E-07 * (300./ZTE(I)) ** 0.39
+      KZ(24,I) = 1.95E-07 * (300./ZTE(I)) ** 0.70
+      IF (ZTE(I) .GE. 1200.) KZ(24,I) = 1.6E-07 * (300./ZTE(I)) ** 0.55
+      KZ(25,I) = 6.0E-10
+      KZ(26,I) = 3.1E-11
+      KZ(27,I) = 3.0E-12
+      IF (ZTE(I) .LT. 500.) THEN
+        KZ(28,I) = 1.0E-29
+      ELSE
+        KZ(28,I) = 2.6E-11 * ZTE(I)**0.5 * EXP(-22740./ZTE(I))
+      ENDIF
+      KZ(29,I) = 4.1E-12
+      KZ(30,I) = 4.4E-10
+      KZ(31,I) = 7.0E-11
+      KZ(32,I) = 1.0E-12
+      KZ(33,I) = 1.2E-11
+      KZ(34,I) = 2.0E-12
+      KZ(35,I) = 1.8E-10
+      KZ(36,I) = 4.0E-12 * EXP(-865./ZTN(I))
+      KZ(37,I) = 1.2E-10
+      KZ(38,I) = 1.3E-10
+      KZ(39,I) = 2.0E-11
+      IF (T5(I) .LT. 5) THEN
+        KZ(40,I) = 8.36E-13 - 2.02E-13*T5(I) + 6.95E-14*T5(I)**2
+      ELSE
+        KZ(40,I) = 5.33E-13 - 1.64E-14*T5(I) + 4.72E-14*T5(I)**2 &
+                            - 7.05E-16*T5(I)**3
+      ENDIF
+      KZ(41,I) = 7.3E-13
+      KZ(42,I) = 1.3E-15
+      KZ(43,I) = 1.0E-7
+      KZ(44,I) = 1.4E-10
+      KZ(45,I) = 4.0E-13
+    ENDDO
 !
 !
 ! Calculate Electron impact ionization, photoionization, and electron
